@@ -61,7 +61,7 @@ def get_fft_freqs(data_row):
 
 def get_fft_level(data_row, X_q=None):
     if X_q is None:
-        X_q = get_X_q(data_row.time_row)
+        X_q = get_X_q(data_row.time_var)
     res = data_row.values.var() * X_q / data_row.time_var.size
     return res
 
